# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify CentOS Linux and Scientific Linux as rhel
%if "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "sl" || "%{__distinit}" == "sls"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

# We don't really need ExtUtils::MakeMaker ≥ 6.30
%global old_eumm %(perl -MExtUtils::MakeMaker -e 'print (($ExtUtils::MakeMaker::VERSION < 6.30) ? 1 : 0);' 2>/dev/null || echo 0)

# We need to patch the test suite if we have an old version of Test::More
%global old_test_more %(perl -MTest::More -e 'print (($Test::More::VERSION < 0.88) ? 1 : 0);' 2>/dev/null || echo 0)
%global older_test_more %(perl -MTest::More -e 'print (($Test::More::VERSION < 0.82) ? 1 : 0);' 2>/dev/null || echo 0)

Name:		perl-Data-OptList
Version:	0.109
Release:	1.%{__distinit}%{__distvers}
Summary:	Parse and validate simple name/value option pairs
License:	GPL+ or Artistic
Group:		Development/Libraries
URL:		http://search.cpan.org/dist/Data-OptList/
Source0:	http://search.cpan.org/CPAN/authors/id/R/RJ/RJBS/Data-OptList-%{version}.tar.gz
Patch0:		Data-OptList-0.108-old-eu::mm.patch
Patch1:		Data-OptList-0.109-old-Test::More.patch
Patch2:		Data-OptList-0.109-note.patch
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-root-%(id -nu)
BuildArch:	noarch
BuildRequires:	perl(ExtUtils::MakeMaker) >= 6.17
BuildRequires:	perl(List::Util)
BuildRequires:	perl(Params::Util)
BuildRequires:	perl(Sub::Install) >= 0.921
BuildRequires:	perl(Test::More) >= 0.47
BuildRequires:	perl(Test::Pod) >= 1.41
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))

%description
Hashes are great for storing named data, but if you want more than one entry
for a name, you have to use a list of pairs. Even then, this is really boring
to write:

$values = [
    foo => undef,
    bar => undef,
    baz => undef,
    xyz => { ... },
];

With Data::OptList, you can do this instead:

$values = Data::OptList::mkopt([
    qw(foo bar baz),
    xyz => { ... },
]);

This works by assuming that any defined scalar is a name and any reference
following a name is its value.

%prep
%setup -q -n Data-OptList-%{version}

# We don't really need ExtUtils::MakeMaker ≥ 6.30
%if %{old_eumm}
%patch0
%endif

# We don't really need Test::More ≥ 0.88
%if %{old_test_more}
%patch1
%endif

# We don't really need Test::More ≥ 0.82 either
%if %{older_test_more}
%patch2
%endif

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
rm -rf %{buildroot}
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -exec rm -f {} \;
%{_fixperms} %{buildroot}

%check
make test
make test TEST_FILES="$(echo $(find xt/ -name '*.t'))"

%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root,-)
%doc Changes LICENSE README
%{perl_vendorlib}/Data/
%{_mandir}/man3/Data::OptList.3pm*

%changelog
* Fri Dec 13 2013 Paul Howarth <paul@city-fan.org> 0.109-1
- update to 0.109:
  - update bugtracker and repo links
- update patches as needed

* Thu Jul 18 2013 Paul Howarth <paul@city-fan.org> 0.108-2
- Perl 5.18 rebuild

* Sat Jul  6 2013 Paul Howarth <paul@city-fan.org> 0.108-1
- update to 0.108:
  - repackage, new bug tracker
- explicitly run the extra tests
- update patches
- add new patch to support build with Test::More < 0.82 (note)

* Tue Jul  3 2012 Paul Howarth <paul@city-fan.org> 0.107-6
- don't need to remove empty directories from the buildroot
- drop support for old distributions prior to FC-3:
  - don't need to define %%{perl_vendorlib}
  - use DESTDIR rather than PERL_INSTALL_ROOT

* Fri Jan 20 2012 Paul Howarth <paul@city-fan.org> 0.107-3
- drop redundant buildreq perl(Test::Pod::Coverage)
- BR: perl(ExtUtils::MakeMaker), perl(List::Util) and perl(Test::More)

* Thu Jun 23 2011 Paul Howarth <paul@city-fan.org> 0.107-2
- rebuild for perl 5.14.1 in Rawhide
- fix dist tag for CentOS 6 and Scientific Linux

* Fri May  6 2011 Paul Howarth <paul@city-fan.org> 0.107-1
- update to 0.107:
  - mkopt now prefers named parameters; docs updated
  - added the name_test parameter to mkopt
- nobody else likes macros for commands

* Wed Jun 23 2010 Paul Howarth <paul@city-fan.org> 0.106-3
- rebuild for perl 5.12.1 in Rawhide

* Tue Jun  8 2010 Paul Howarth <paul@city-fan.org> 0.106-2
- fix dist tag for RHEL-6 Beta

* Mon Feb 15 2010 Paul Howarth <paul@city-fan.org> 0.106-1
- update to 0.106 (correct version style mismatch for Sub::Install)
- bump dependency on Sub::Install to 0.921
- use %%{_fixperms} macro instead of our own %%{__chmod} incantation

* Fri Jan 15 2010 Paul Howarth <paul@city-fan.org> 0.105-1
- update to 0.105 (fix a typo in documentation)

* Wed Sep  9 2009 Paul Howarth <paul@city-fan.org> 0.104-2
- define RPM macros in global scope

* Thu Jan 22 2009 Paul Howarth <paul@city-fan.org> 0.104-1
- update to 0.104

* Mon Sep  1 2008 Paul Howarth <paul@city-fan.org> 0.103-3
- import from Fedora

* Wed Feb 27 2008 Tom "spot" Callaway <tcallawa@redhat.com> 0.103-2
- rebuild for perl 5.10 (again)

* Thu Jan 24 2008 Tom "spot" Callaway <tcallawa@redhat.com> 0.103-1
- rebuild for new perl
- bump to 0.103
- fix license tag

* Thu Sep 07 2006 Chris Weyl <cweyl@alumni.drew.edu> 0.101-2
- bump

* Sat Sep 02 2006 Chris Weyl <cweyl@alumni.drew.edu> 0.101-1
- Specfile autogenerated by cpanspec 1.69.1.
